//
//  PersistentContainer.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/31/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation
import CoreData

final class PersistentContainer {
    
    private let dataModelName = "SessionModel"
    
    private lazy var persistentContainer: NSPersistentContainer = {
        let container = NSPersistentContainer(name: dataModelName)
        
        container.loadPersistentStores { description, error in
            if let error {
                fatalError("Unable to load persistent stores: \(error)")
            }
            else {
                print("Loaded persistent store: \(description)")
            }
        }
        
        return container
    }()
    
    private var _backgroundContext: NSManagedObjectContext?
    
    var backgroundContext: NSManagedObjectContext {
        if _backgroundContext == nil {
            _backgroundContext = persistentContainer.newBackgroundContext()
        }
        return _backgroundContext!
    }
    
    var viewContext: NSManagedObjectContext {
        persistentContainer.viewContext
    }
    
    func save(context: NSManagedObjectContext) {
        
        guard context.hasChanges else { return }
        
        context.perform { self.save(context) }
    }
    
    func saveAndWait(context: NSManagedObjectContext) {
        
        guard context.hasChanges else { return }
        
        context.performAndWait { save(context) }
    }
}

extension PersistentContainer {
    
    private func save(_ context: NSManagedObjectContext) {
        do {
            try context.save()
        }
        catch {
            print("Error in saving context \(error)")
        }
    }
}
