//
//  ScanSessionPayloadManager.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/6/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

class ScanSessionPayloadManager {
    
    class func getPayload(session: ScanSession, payload: PayloadType) -> [Any] {
        payload == .pdf ? getPDFPayload(session: session) : getJPEGPayload(session: session)
    }
    
    private class func getJPEGPayload(session: ScanSession) -> [URL] {
        
        var images: [URL] = []
        
        var scannedItems = session.scannedItems.filter { $0.isSelected }
        
        if scannedItems.isEmpty {
            scannedItems = session.scannedItems
        }
        
        for scannedItem in scannedItems {
            
            if let image = scannedItem.newRenderedImage {
                
                images.append(image)
            }
        }
        
        return images
    }
    
    private class func getPDFPayload(session: ScanSession) -> [URL] {
        
        var documents: [URL] = []
        
        var scannedItems = session.scannedItems.filter { $0.isSelected }
        
        if scannedItems.isEmpty {
            scannedItems = session.scannedItems
        }
        
        let pdfFileURL = PDFManager.createPDFFile(session: session,
                                                  scannedItems: scannedItems)
        
        documents.append(pdfFileURL)
        
        return documents
    }
    
    class func deleteTempPDFFileIfNeeded(session: ScanSession, shareType: ShareType) {
        
        if shareType == .pdf {
            PDFManager.deletePDFFile(session: session)
        }
    }
}
