//
//  ScanSessionPrintable.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/6/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit

protocol ScanSessionPrintable: UIPrintInteractionControllerDelegate {
    
    var activityIndicator: UIActivityIndicatorView { get set }
    
    var shareType: ShareType { get set }
}

extension ScanSessionPrintable {
    
    func printScanSession(session: ScanSession) {
        
        activityIndicator.startAnimating()
        
        Task {
            
            let payload = ScanSessionPayloadManager.getPayload(session: session, payload: shareType.payloadType)
            
            DispatchQueue.main.async {
                
                self.activityIndicator.stopAnimating()
                
                self.displayPrintSheet(name: session.name, printingItems: payload)
            }
        }
    }
    
    func printControllerDidDismiss(session: ScanSession) {
        
        ScanSessionPayloadManager.deleteTempPDFFileIfNeeded(session: session, shareType: shareType)
    }
}

extension ScanSessionPrintable {
    
    private func displayPrintSheet(name: String, printingItems: [Any]) {
        let printInfo = UIPrintInfo(dictionary: nil)
        
        printInfo.jobName = name
        printInfo.outputType = .general
        
        let printController = UIPrintInteractionController.shared
        
        printController.printInfo = printInfo
        printController.printingItems = printingItems
        printController.delegate = self
        
        printController.present(animated: true, completionHandler: nil)
    }
}
