import UIKit
import IQKeyboardManagerSwift

@main
class AppDelegate: UIResponder, UIApplicationDelegate {
  
  func application(_ application: UIApplication,
                   didFinishLaunchingWithOptions launchOptions: [UIApplication.LaunchOptionsKey: Any]?) -> Bool {
    // Override point for customization after application launch.
      
      initializeDependencies()
      
      @Inject var handleAppLanguageUseCase: HandleAppLanguageUseCase
      handleAppLanguageUseCase.execute()
      
      IQKeyboardManager.shared.enable = true
      IQKeyboardManager.shared.resignOnTouchOutside = true
      IQKeyboardManager.shared.toolbarConfiguration.previousNextDisplayMode = .alwaysShow
      IQKeyboardManager.shared.toolbarConfiguration.tintColor = ColorStyle.primary.uiColor

      return true
  }
  
  // MARK: UISceneSession Lifecycle
  
  func application(_ application: UIApplication,
                   configurationForConnecting connectingSceneSession: UISceneSession,
                   options: UIScene.ConnectionOptions) -> UISceneConfiguration {
    // Called when a new scene session is being created.
    // Use this method to select a configuration to create the new scene with.
    return UISceneConfiguration(name: "Default Configuration", sessionRole: connectingSceneSession.role)
  }
  
  func application(_ application: UIApplication, didDiscardSceneSessions sceneSessions: Set<UISceneSession>) {
    // Called when the user discards a scene session.
    // If any sessions were discarded while the application was not running, this will be called shortly after application:didFinishLaunchingWithOptions.
    // Use this method to release any resources that were specific to the discarded scenes, as they will not return.
  }
}

struct AppConfigurator {
  // Privacy policies and term links
    enum Settings: String {
        case terms = "https://mistergrizzly.com/terms-and-conditions/"
        case privacy = "https://mistergrizzly.com/privacy-policy/"
    }
    
    enum Folders: String {
        case AllDocument = "AllDocument"
    }
    
    struct Folder: Codable, Hashable {
        var name: String
        var savedName: String
        var isSelected: Bool
        var canBeDeleted: Bool?
        
        var localizedName: String {
            switch savedName {
            case "all_documents":
                return .allDocuments.localized
            case "passports":
                return .passports.localized
            case "contracts":
                return .contracts.localized
            case "identifiers":
                return .identifiers.localized
            default:
                return name
            }
        }
    }
    
  static let ThumbnailsFolderName = ".ThumbnailImages"
}

let deviceType = UIDevice.current.userInterfaceIdiom

extension Bundle {
  class var appName: String {
    let bundleDisplayname = Bundle.main.infoDictionary?["CFBundleDisplayName"] as? String
    let bundleName = Bundle.main.infoDictionary![kCFBundleNameKey as String] as! String
    
    return bundleDisplayname ?? bundleName
  }
}

extension AppDelegate {
    
    private func initializeDependencies() {
        _ = DependencyManager()
    }
}
