//
//  DependencyInjector.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/17/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

struct DependencyInjector {
    
    private static var dependencyList: [String: Any] = [:]
    
    static func resolve<T>() -> T {
        guard let t = dependencyList[String(describing: T.self)] as? T else {
            fatalError("No provider registerd for type: \(T.self)")
        }
        return t
    }
    
    static func register<T>(dependency: T) {
        dependencyList[String(describing: T.self)] = dependency
    }
    
    static func clear<T>(dependency: T) {
        dependencyList.removeValue(forKey: String(describing: T.self))
    }
}
