//
//  View+CustomSheet.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/13/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import SwiftUI

struct CustomSheetModifier<SheetContent: View>: ViewModifier {
    
    var isPresented: Binding<Bool>
    var dismissable: Bool = true
    var height: CGFloat
    var detents: [BottomSheet.Detent]
    @ViewBuilder var sheetContent: () -> SheetContent
    
    func body(content: Content) -> some View {
        
        if #available(iOS 16.0, *) {
            iOS16View(content: content)
        } else {
            iOS15View(content: content)
        }
    }
    
    @available(iOS 16.0, *)
    private func iOS16View(content: Content) -> some View {
        
        content
            .sheet(isPresented: isPresented) {
                
                sheetContent()
                    .presentationDetents([.height(height)])
                    .interactiveDismissDisabled(!dismissable)
            }
    }
    
    private func iOS15View(content: Content) -> some View {
        
        content
            .bottomSheet(isPresented: isPresented,
                         detents: detents,
                         shouldScrollExpandSheet: true,
                         showGrabber: false,
                         showNavigationBar: true,
                         dismissable: dismissable,
                         content: sheetContent)
    }
}

extension View {
    
    func customSheet<Content: View>(isPresented: Binding<Bool>,
                                    dismissable: Bool = true,
                                    height: CGFloat,
                                    detents: [BottomSheet.Detent],
                                    @ViewBuilder content: @escaping () -> Content) -> some View {
        
        ModifiedContent(content: self, modifier: CustomSheetModifier(isPresented: isPresented, dismissable: dismissable, height: height, detents: detents, sheetContent: content))
    }
}
