//
//  View+CustomColor.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/13/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import SwiftUI

struct CustomColorModifier: ViewModifier {
    
    var color: ColorStyle
    var place: ColorPlace
    
    func body(content: Content) -> some View {
        
        switch place {
        case .background:
            
            content
                .background(color.color)
            
        case .foreground:
            
            content
                .foregroundStyle(color.color)
        }
    }
}

extension View {
    
    func customForeground(_ color: ColorStyle) -> some View {
        ModifiedContent(content: self, modifier: CustomColorModifier(color: color, place: .foreground))
    }
    
    func customBackground(_ color: ColorStyle) -> some View {
        ModifiedContent(content: self, modifier: CustomColorModifier(color: color, place: .background))
    }
}

enum ColorPlace {
    case background
    case foreground
}
