//
//  View+LayoutChanges.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/18/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import SwiftUI

struct LayoutChangesModifier: ViewModifier {
    
    @State var layoutDirection: LayoutDirection = .leftToRight
    
    @Inject var getLanguageUseCase: GetLanguageUseCase
    
    func body(content: Content) -> some View {
        
        content
            .onAppear {
                updateLayoutDirection()
            }
            .environment(\.layoutDirection, layoutDirection)
    }
    
    private func updateLayoutDirection() {
        let language = getLanguageUseCase.execute()
        layoutDirection = language.layoutDirection
    }
}

extension View {
    
    func handleLayoutChanges() -> some View {
        ModifiedContent(content: self,
                        modifier: LayoutChangesModifier())
    }
}
