//
//  View+ReadSize.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/13/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import SwiftUI

struct ReadSizeModifier: ViewModifier {
    
    var onChange: GenericAction<CGSize>
    @Binding var size: CGSize
    
    func body(content: Content) -> some View {
        
        content
            .background {
                
                GeometryReader { proxy in
                    
                    Color.clear
                        .preference(key: SizePreferenceKey.self, value: proxy.size)
                }
            }
            .onPreferenceChange(SizePreferenceKey.self) { onChange?($0) }
            .onPreferenceChange(SizePreferenceKey.self) { size = $0 }
    }
}

extension View {
    
    func readSize(onChange: GenericAction<CGSize>) -> some View {
        ModifiedContent(content: self, modifier: ReadSizeModifier(onChange: onChange, size: .constant(.zero)))
    }
    
    func readSize(size: Binding<CGSize>) -> some View {
        ModifiedContent(content: self, modifier: ReadSizeModifier(onChange: nil, size: size))
    }
}

fileprivate struct SizePreferenceKey: PreferenceKey {
    static var defaultValue: CGSize = .zero
    
    static func reduce(value: inout CGSize, nextValue: () -> CGSize) { }
}
