//
//  NoIndicatorsScrollView.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/21/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import SwiftUI

struct NoIndicatorsScrollView<Content: View>: View {
    
    var axes: Axis.Set = .vertical
    @ViewBuilder var content: () -> Content
    
    var body: some View {
        if #available(iOS 16.0, *) {
            return iOS16Body
        } else {
            return iOS15Body
        }
    }
    
    @available(iOS 16.0, *)
    private var iOS16Body: some View {
        ScrollView(axes, content: content)
            .scrollIndicators(.hidden)
    }
    
    private var iOS15Body: some View {
        ScrollView(axes, showsIndicators: false, content: content)
    }
}

#Preview {
    NoIndicatorsScrollView { }
}
