//
//  CustomPicker.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/13/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import SwiftUI

struct CustomPicker<Item: CustomMenuPickerItem>: View {
    
    @Binding var selectedItem: Item
    var items: [Item]
    
    var body: some View {
        VStack(spacing: 8) {
            
            ForEach(items) { item in
                
                getItemView(for: item)
            }
        }
    }
    
    private func getItemView(for item: Item) -> some View {
        Button(action: {
            selectedItem = item
        }, label: {
            
            HStack {
                
                Text(item.displayedName)
                    .customForeground(.gray600)
                    .customFont(.bold(20))
                
                Spacer()
                
                if item == selectedItem {
                    
                    Image.checkmark
                        .resizable()
                        .aspectRatio(contentMode: .fit)
                        .frame(width: 12, height: 12)
                        .customForeground(.primary)
                }
            }
            .frame(maxWidth: .infinity)
            .padding(.horizontal, 16)
            .padding(.vertical, 10)
        })
    }
}
