import UIKit

enum TimePeriod: TimeInterval {
    case Second = 1
    case Minute = 60
    case Hour = 3600
    case Day = 86400
    case Week = 604800
}

extension Date {
  func isSameWeekAsDate(_ date: Date) -> Bool {
    let calendar = Calendar.current
    let comps: Set<Calendar.Component> = [Calendar.Component.year,
                                       Calendar.Component.month,
                                       Calendar.Component.day,
                                       Calendar.Component.weekOfYear,
                                       Calendar.Component.hour,
                                       Calendar.Component.minute,
                                       Calendar.Component.second,
                                       Calendar.Component.weekday,
                                       Calendar.Component.weekdayOrdinal]
    
    let components1 = calendar.dateComponents(comps, from: self)
    let components2 = calendar.dateComponents(comps, from: date)

    // Must be same week. 12/31 and 1/1 will both be week "1" if they are in the same week
    if components1.weekOfYear != components2.weekOfYear {
      return false
    }

    return abs(timeIntervalSince(date)) < TimePeriod.Week.rawValue
  }
    
    func getScanSessionCreatingDateString() -> String {
        var dateString = ""
        
        if Calendar.current.isDateInToday(self) {
            dateString = .today
            
        } else if Calendar.current.isDateInYesterday(self) {
            dateString = .yesterday
            
        } else if isSameWeekAsDate(self) {
            dateString = .thisWeek
            
        } else {
            let currentLocale = SupportedLanguage.currentLanguage.locale
            let dateFormatter = DateFormatter()
            let dateComponents = "yyyy-MM-dd"
            
            let dateFormat = DateFormatter.dateFormat(fromTemplate: dateComponents, options: 0, locale: currentLocale)
            
            dateFormatter.dateFormat = dateFormat
            
            dateString = dateFormatter.string(from: self)
        }
        
        return dateString
    }
}
