//
//  UIFont+Extensions.swift
//  MiniScanner
//
//  Created by George Makhoul on 08/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit

extension UIFont {
    
    // MARK: - Font Name
    enum AppFont {
        
        case bold
        case semibold
        case medium
        case regular
        case light
        case extraLight
        case thin
        
        enum English: String {
            
            case bold
            case semibold
            case medium
            case regular
            case light
            case extraLight
            case thin
        }
        
        private var weight: String {
            switch self {
            case .bold:
                "Bold"
            case .semibold:
                "SemiBold"
            case .medium:
                "Medium"
            case .regular:
                "Regular"
            case .light:
                "Light"
            case .extraLight:
                "ExtraLight"
            case .thin:
                "Thin"
            }
        }
        
        private var fontName: String {
            SupportedLanguage.currentLanguage == .english ? "Metropolis" : "IBMPlexSansArabic"
        }
        
        func font() -> String {
            "".appendingFormat("%@-%@",
                               fontName,
                               weight)
        }
    }
}

extension UIFont {
    
    // MARK: - Get Font
    
    static func getFont(_ name: UIFont.AppFont, size: CGFloat) -> UIFont {
        return getFont(name: name.font(), size: size)
    }
    
    static func getFont(name: String, size: CGFloat) -> UIFont {
        if let font = UIFont(name: name, size: size) {
            return font
        } else {
            return UIFont.systemFont(ofSize: size)
        }
    }
    
    // MARK: - Font Styles
    
    class func regular(_ size: CGFloat) -> UIFont {
        getFont(.regular, size: size)
    }
    
    class func medium(_ size: CGFloat) -> UIFont {
        getFont(.medium, size: size)
    }
    
    class func semibold(_ size: CGFloat) -> UIFont {
        getFont(.semibold, size: size)
    }
    
    class func bold(_ size: CGFloat) -> UIFont {
        getFont(.bold, size: size)
    }
}
