import UIKit

extension UIImage {
  
  var getJPEGData: Data? {
    return jpegData(compressionQuality: 0.5)
  }
  
  var toFullData: Data? {
    return jpegData(compressionQuality: 1)
  }
}

extension UIImage {
  static func localImage(_ name: String, template: Bool = false) -> UIImage {
    var image = UIImage(named: name)!
    if template {
      image = image.withRenderingMode(.alwaysTemplate)
    }
    return image
  }
}

extension UIImage {
  /// Tint Image
  ///
  /// - Parameter fillColor: UIColor
  /// - Returns: Image with tint color
  func tint(with fillColor: ColorStyle) -> UIImage? {
    let image = withRenderingMode(.alwaysTemplate)
    UIGraphicsBeginImageContextWithOptions(size, false, scale)
      fillColor.uiColor.set()
    image.draw(in: CGRect(origin: .zero, size: size))
    
    guard let imageColored = UIGraphicsGetImageFromCurrentImageContext() else {
      return nil
    }
    
    UIGraphicsEndImageContext()
    return imageColored
  }
}
