//
//  UILabel+Extensions.swift
//  MiniScanner
//
//  Created by George Makhoul on 08/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit

extension UILabel {
    // MARK: - Set Text, Color, Font
    func set(text: String) {
        self.text = text
        alignment()
    }
    
    func set(color: ColorStyle) {
        textColor = color.uiColor
    }
    
    func set(font: UIFont) {
        self.font = font
    }
    
    func set(text: String, color: ColorStyle, font: UIFont) {
        set(text: text)
        set(color: color)
        set(font: font)
    }
    
    func set(uppercased: String) {
        text = uppercased.uppercased()
        alignment()
    }
    
    func set(uppercased: String, color: ColorStyle, font: UIFont) {
        set(uppercased: uppercased)
        set(font: font)
        set(color: color)
    }
    
    // MARK: - Localization
    func set(localized: String) {
        text = localized.localized
        alignment()
    }
    
    func set(localizedUppercased: String) {
        text = localizedUppercased.localized.uppercased()
        alignment()
    }
    
    func set(localized: String, color: ColorStyle, font: UIFont) {
        set(localized: localized)
        set(font: font)
        set(color: color)
    }
    
    func set(localizedUppercased: String, color: ColorStyle, font: UIFont) {
        set(localizedUppercased: localizedUppercased)
        set(font: font)
        set(color: color)
    }
    
    // MARK: - Alignment
    func alignment() {
        textAlignment = SupportedLanguage.currentLanguage.isRTL ? .right : .left
    }
    
    func align(to alignment: NSTextAlignment) {
        textAlignment = alignment
    }
}
