//
//  DependencyManager.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/17/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

final class DependencyManager {
    
    let userDefaultsManager: UserDefaultsManagerProtocol
    let coreDataManager: CoreDataManagerProtocol
    let persistantContainer: PersistentContainer
    let userSettings: UserSettings
    
    init() {
        self.userDefaultsManager = UserDefaultsManager()
        
        self.persistantContainer = PersistentContainer()
        self.coreDataManager = CoreDataManager(persistentContainer: persistantContainer)
        self.userSettings = UserSettings(userDefaultsManager: userDefaultsManager)
        
        initializeDependencies()
    }
    
    private func initializeDependencies() {
        initializeSettingsDependencies()
        
        _ = ScanSessionDependencyManager(coreDataManager: coreDataManager)
    }
    
    private func initializeSettingsDependencies() {
        
        let dataSource = SettingsDataSource(userDefaultsManager: userDefaultsManager)
        let repository = SettingsRepository(dataSource: dataSource)
        
        @Provide var userSettings = userSettings
        
        @Provide var getLanguagesUseCase = GetLanguagesUseCase(repository: repository)
        @Provide var getLanguageUseCase = GetLanguageUseCase(repository: repository)
        @Provide var changeLanguageUseCase = ChangeLanguageUseCase(repository: repository)
        
        @Provide var getColorSchemeUseCase = GetColorSchemeUseCase(repository: repository)
        @Provide var changeColorSchemeUseCase = ChangeColorSchemeUseCase(repository: repository)
        
        @Provide var handleAppStartUseCase = HandleAppStartUseCase(repository: repository)
        
        @Provide var handleAppLanguageUseCase = HandleAppLanguageUseCase(repository: repository)
    }
}
