//
//  UserSettings.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/13/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

class UserSettings {
    
    private let userDefaultsManager: UserDefaultsManagerProtocol
    
    init(userDefaultsManager: UserDefaultsManagerProtocol) {
        self.userDefaultsManager = userDefaultsManager
    }
    
    private var _defaultFileType: DefaultFileType?
    private var _defaultScreen: DefaultScreen?
    
    var defaultFileType: DefaultFileType {
        get {
            
            if _defaultFileType == nil {
                
                _defaultFileType = userDefaultsManager.get(key: .defaultFileType) ?? .pdf
            }
            
            return _defaultFileType!
        }
        set {
            _defaultFileType = newValue
            
            userDefaultsManager.set(value: newValue, key: .defaultFileType)
        }
    }
    
    var defaultScreen: DefaultScreen {
        get {
            
            if _defaultScreen == nil {
                
                _defaultScreen = userDefaultsManager.get(key: .defaultScreen) ?? .files
            }
            
            return _defaultScreen!
        }
        set {
            _defaultScreen = newValue
            
            userDefaultsManager.set(value: newValue, key: .defaultScreen)
        }
    }
}
