//
//  SupportedColorScheme.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/17/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

enum SupportedColorScheme: String, CaseIterable, CustomMenuPickerItem {
    
    case device
    case light
    case dark
    
    var id: Self { self }
    
    var displayedName: String {
        switch self {
        case .device:
                .basedOnDevice.localized
        case .light:
                .light.localized
        case .dark:
                .dark.localized
        }
    }
}

extension SupportedColorScheme {
    
    static func from(codeName: String) -> SupportedColorScheme {
        SupportedColorScheme(rawValue: codeName) ?? .device
    }
    
    var codeName: String {
        rawValue
    }
}
