//
//  ScanSessionDependencyManager.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/31/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

class ScanSessionDependencyManager {
    
    let coreDataManager: CoreDataManagerProtocol
    
    init(coreDataManager: CoreDataManagerProtocol) {
        self.coreDataManager = coreDataManager
        initializeDependencies()
    }
    
    private func initializeDependencies() {
        initializeScanDependencies()
    }
    
    private func initializeScanDependencies() {
        
        let dataSource = ScanSessionsDataSource(coreDataManager: coreDataManager)
        
        let repository = ScanSessionsRepository(dataSource: dataSource)
        
        @Provide var getFoldersUseCase = GetFoldersUseCase(repository: repository)
        @Provide var addFolderUseCase = AddFolderUseCase(repository: repository)
        @Provide var updateFolderUseCase = UpdateFolderUseCase(repository: repository)
        @Provide var deleteFolderUseCase = DeleteFolderUseCase(repository: repository)
        
        @Provide var getScanSessionsUseCase = GetScanSessionsUseCase(repository: repository)
        @Provide var addScanSessionUseCase = AddScanSessionUseCase(repository: repository)
        @Provide var updateScanSessionUseCase = UpdateScanSessionUseCase(repository: repository)
        @Provide var moveScanSessionUseCase = MoveScanSessionUseCase(repository: repository)
        @Provide var deleteScanSessionUseCase = DeleteScanSessionUseCase(repository: repository)
    }
}
