//
//  ScanSessionsDataSource.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/31/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

protocol ScanSessionsDataSourceProtocol {
    
    func getFolders() -> [FolderEntity]
    func createFolderEntity() -> FolderEntity
    func deleteFolder(folder: FolderEntity)
    
    func getScanSessions() -> [ScanSessionEntity]
    func createScanSessionEntity() -> ScanSessionEntity
    func addScanSession(session: ScanSessionEntity, to folder: FolderEntity)
    func deleteScanSession(session: ScanSessionEntity)
    
    func saveChanges()
    func saveChangesAndWait()
}

class ScanSessionsDataSource: ScanSessionsDataSourceProtocol {
    
    let coreDataManager: CoreDataManagerProtocol
    
    init(coreDataManager: CoreDataManagerProtocol) {
        self.coreDataManager = coreDataManager
    }
}

extension ScanSessionsDataSource {
    
    func getFolders() -> [FolderEntity] {
        coreDataManager.fetchFolders()
    }
    
    func createFolderEntity() -> FolderEntity {
        coreDataManager.createFolderEntity()
    }
    
    func deleteFolder(folder: FolderEntity) {
        coreDataManager.deleteFolder(folder: folder)
    }
}

extension ScanSessionsDataSource {
    
    func getScanSessions() -> [ScanSessionEntity] {
        coreDataManager.fetchScanSessions()
    }
    
    func createScanSessionEntity() -> ScanSessionEntity {
        coreDataManager.createScanSessionEntity()
    }
    
    func addScanSession(session: ScanSessionEntity, to folder: FolderEntity) {
        folder.addToSessions(session)
    }
    
    func deleteScanSession(session: ScanSessionEntity) {
        coreDataManager.deleteScanSession(session: session)
    }
}

extension ScanSessionsDataSource {
    
    func saveChanges() {
        coreDataManager.saveChanges()
    }
    
    func saveChangesAndWait() {
        coreDataManager.saveChangesAndWait()
    }
}
