//
//  Folder.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/31/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

struct Folder: Identifiable {
    
    let id: UUID
    var name: String
    var isSelected: Bool = false
    var canBeDeleted: Bool = true
    
    var scanSessions: [ScanSession] = []
    
    var localizedName: String {
        switch name.lowercased() {
        case "all_documents":
            return .allDocuments.localized
        case "passports":
            return .passports.localized
        case "contracts":
            return .contracts.localized
        case "identifiers":
            return .identifiers.localized
        default:
            return name
        }
    }
}

extension Folder: Equatable {
    
    static func == (lhs: Folder, rhs: Folder) -> Bool {
        lhs.id == rhs.id
    }
}

extension Folder {
    
    static let allDocuments = Folder(id: UUID(), name: .allDocuments, canBeDeleted: false)
}
