//
//  ScanSession.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/31/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

class ScanSession: Identifiable {
    
    let id: UUID
    var name: String
    var creationDate: Date
    var scannedItems: [ScannedItem]
    
    var folderId: UUID?
    var itemsCount: Int { scannedItems.count }
    
    lazy var creatingDateString: String = {
        creationDate.getScanSessionCreatingDateString()
    }()
    
    init(id: UUID,
         name: String,
         creationDate: Date,
         folderId: UUID? = nil,
         scannedItems: [ScannedItem] = []) {
        self.id = id
        self.name = name
        self.creationDate = creationDate
        self.folderId = folderId
        self.scannedItems = scannedItems
    }
    
    func add(item: ScannedItem) {
        scannedItems.append(item)
    }
    
    func add(item: ScannedItem, at: Int) {
        scannedItems.insert(item, at: at)
    }
    
    func add(items: [ScannedItem]) {
        scannedItems.append(contentsOf: items)
    }
    
    func removeItem(at index: Int) {
        scannedItems.remove(at: index)
    }
    
    func removeItem(item: ScannedItem) {
        scannedItems.remove(element: item)
    }
    
    func replaceItem(with item: ScannedItem, at: Int) {
        if (scannedItems.indices.contains(at)) {
            scannedItems[at] = item
        }
    }
    
    func replaceItemAndGet(item: ScannedItem, at: Int) -> ScanSession {
        if (scannedItems.indices.contains(at)) {
            scannedItems[at] = item
        }
        
        return self
    }
    
    func clearItems() {
        scannedItems.removeAll()
    }
}

extension ScanSession: Equatable {
    
    static func == (lhs: ScanSession, rhs: ScanSession) -> Bool {
        lhs.id == rhs.id
    }
}

extension ScanSession {
    
    static func newSession() -> ScanSession {
        ScanSession(id: UUID(), name: "", creationDate: .now)
    }
    
    static let empty = ScanSession(id: UUID(), name: "empty", creationDate: .now)
}
