//
//  SessionMapper.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/31/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

extension Folder {
    
    func toEntity(entity: FolderEntity) -> FolderEntity {
        let entity = entity
        
        entity.id = id
        entity.name = name
        
        return entity
    }
}

extension FolderEntity {
    
    func copyValues(from folder: Folder) {
        name = folder.name
    }
    
    func toDomain() -> Folder {
        
        let sessions = sessions?.allObjects as? [ScanSessionEntity] ?? []
        
        return Folder(id: id,
                      name: name,
                      scanSessions: sessions.toDomain())
    }
}

extension [FolderEntity] {
    
    func toDomain() -> [Folder] {
        map { $0.toDomain() }
    }
}

extension ScanSession {
    
    func toEntity(entity: ScanSessionEntity) -> ScanSessionEntity {
        let entity = entity
        
        entity.id = id
        entity.name = name
        entity.creationDate = creationDate
        
        let jsonEncoder = JSONEncoder()
        
        if let data = try? jsonEncoder.encode(scannedItems) {
            entity.data = data
        }
        
        return entity
    }
}

extension ScanSessionEntity {
    
    func copyValues(from session: ScanSession) {
        let jsonEncoder = JSONEncoder()
        
        name = session.name
        creationDate = session.creationDate
        
        if let data = try? jsonEncoder.encode(session.scannedItems) {
            self.data = data
        }
    }
    
    func toDomain() -> ScanSession {
        let jsonDecoder = JSONDecoder()
        
        if let scannedItems = try? jsonDecoder.decode([ScannedItem].self, from: data) {
            
            scannedItems.forEach { $0.type = .local }
            
            return ScanSession(id: id,
                               name: name,
                               creationDate: creationDate,
                               folderId: folder.id,
                               scannedItems: scannedItems)
        }
        
        return .empty
    }
}

extension [ScanSessionEntity] {
    
    func toDomain() -> [ScanSession] {
        map { $0.toDomain() }
    }
}

extension MultiPageScanSession {
    
    func toAppDomain() -> ScanSession {
        ScanSession(id: UUID(),
                    name: "",
                    creationDate: .now,
                    scannedItems: scannedItems)
    }
}

extension ScanSession {
    
    func toScannerDomain() -> MultiPageScanSession {
        let session = MultiPageScanSession()
        session.add(items: scannedItems)
        return session
    }
}
