//
//  ZoomableImageView.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/15/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import SwiftUI

struct ZoomableImageView: View {
    
    @Binding var isPresented: Bool
    
    var title: String
    var size: String
    var image: UIImage
    
    var body: some View {
        VStack(alignment: .leading, spacing: 8) {
            
            close
                .padding(.leading, 8)
            
            Text(title)
                .frame(maxWidth: .infinity)
            
            Text(size)
                .frame(maxWidth: .infinity)
            
            ZoomableScrollView {
                
                Image(uiImage: image)
                    .resizable()
                    .aspectRatio(contentMode: .fit)
            }
        }
    }
    
    private var close: some View {
        Button(action: { isPresented = false }, label: {
            Image.xMark
                .resizable()
                .aspectRatio(contentMode: .fit)
                .frame(width: 16, height: 16)
                .customForeground(.gray600)
        })
    }
}

#Preview {
    ZoomableImageView(isPresented: .constant(true), title: "Title", size: "Size", image: .actions)
}
