//
//  SettingButton.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/13/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import SwiftUI

struct SettingButton: View {
    
    var icon: Image
    var title: String
    var value: String
    var action: EmptyAction
    
    var body: some View {
        HStack {
            
            settings
            
            Spacer()
            
            changeButton
        }
    }
    
    private var settings: some View {
        HStack(alignment: .top, spacing: 20) {
            
            iconView
            
            VStack(alignment: .leading, spacing: 6) {
                
                titleView
                
                valueView
            }
        }
    }
    
    private var iconView: some View {
        icon
            .resizable()
            .aspectRatio(contentMode: .fit)
            .frame(width: 20, height: 20)
            .customForeground(.gray600)
    }
    
    private var titleView: some View {
        Text(title)
            .customForeground(.gray600)
            .customFont(.bold(16))
    }
    
    private var valueView: some View {
        Text(value)
            .customForeground(.gray350)
            .customFont(.regular(16))
    }
    
    private var changeButton: some View {
        Button(action: {
            action?()
        }, label: {
            
            Text(String.change.localized)
                .customForeground(.gray600)
                .customFont(.medium(16))
        })
    }
}

#Preview {
    SettingButton(icon: .chevronBackward,
                  title: "Title",
                  value: "Value",
                  action: { })
}
