//
//  SettingSheetView.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/13/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import SwiftUI

struct SettingSheetView<Item: CustomMenuPickerItem>: View {
    
    @Environment(\.dismiss) var dismiss
    
    var title: String
    
    @Binding var selectedItem: Item
    var items: [Item]
    
    var saveAction: EmptyAction
    
    var body: some View {
        VStack(alignment: .leading, spacing: 30) {
            
            titleView
            
            picker
            
            save
        }
        .padding(.vertical, 16)
        .padding(.horizontal, 16)
        .customCornerRadii(50, corners: [.topLeft, .topRight])
        .handleLayoutChanges()
    }
}

extension SettingSheetView {
    
    private var titleView: some View {
        Text(title)
            .customForeground(.gray600)
            .customFont(.bold(24))
    }
    
    private var picker: some View {
        CustomPicker(selectedItem: $selectedItem,
                     items: items)
    }
    
    private var save: some View {
        PrimaryButton(title: .save.localized) {
            saveAction?()
            dismiss()
        }
    }
}
