//
//  SettingsViewCoordinator.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/18/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation
import PhotosUI

protocol SettingsViewCoordinating: MainCoordinator {
    var navigationController: UINavigationController { get set }
    
    func coordinateToCredits()
    func displayImagePicker(delegate: PHPickerViewControllerDelegate)
}

class SettingsViewCoordinator: SettingsViewCoordinating {
    
    var navigationController: UINavigationController
    
    init(navigationController: UINavigationController) {
        self.navigationController = navigationController
    }
    
    func start() {
        let view = SettingsView(coordinator: self)
        coordinateToView(view, title: .settings.localized)
    }
    
    func coordinateToCredits() {
        
        let coordinator = CreditsViewCoordinator(navigationController: navigationController)
        
        coordinate(to: coordinator)
    }
    
    func displayImagePicker(delegate: PHPickerViewControllerDelegate) {
        var configuration = PHPickerConfiguration()
        configuration.selectionLimit = 1
        configuration.filter = .images
        let picker = PHPickerViewController(configuration: configuration)
        
        picker.delegate = delegate
        
        picker.modalPresentationStyle = .fullScreen
        
        navigationController.present(picker, animated: true, completion: nil)
    }
}
