//
//  Globals.swift
//  MiniScanner
//
//  Created by George Makhoul on 09/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation
import UIKit

typealias AlertViewClosure = () -> ()
typealias AlertViewTextClosure = (String) -> ()

// Global Alert
@discardableResult
func alert(confirm: String,
           destructive: String,
           image: UIImage,
           title: String,
           message: String,
           needsFolderTextField: Bool = true,
           vcToPresent: UIViewController? = nil,
           _ completion: AlertViewTextClosure?,
           _ cancelCompletion: AlertViewClosure? = nil) -> KNAlertViewController {
    
    let vc = KNAlertViewController(type: .decision,
                                   image: image,
                                   title: title.localized,
                                   message: message.localized,
                                   confirm: confirm.localized,
                                   destructive: destructive.localized,
                                   needsFolderTextField: needsFolderTextField)
    vc.modalPresentationStyle = .overFullScreen
    vc.modalTransitionStyle = .crossDissolve
    vc.confirmClosure = completion
    vc.destructiveClosure = cancelCompletion
    
    // Todo to be removed when detecting the error of twice appearing in the pop-up.
    
    if let vcToPresent = vcToPresent {
        vcToPresent.present(vc, animated: false, completion: nil)
        
    } else {
        if let topV = topViewController() as? KNAlertViewController {
            return topV
        }
        topViewController()?.present(vc, animated: false, completion: nil)
    }    
    return vc
}

