//
//  ScannedItemPreviewPagerViewCell.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/13/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

class ScannedItemPreviewPagerViewCell: FSPagerViewCell {
    
    private lazy var scrollView: UIScrollView = {
        
        var width = contentView.frame.width
        var height = contentView.frame.height
        
        var scrollView: UIScrollView = UIScrollView(frame: CGRect(x: 0, y: 0, width: width, height: height))
        scrollView.delegate = self
        
        scrollView.customBackground(.clear)
        
        scrollView.alwaysBounceVertical = false
        scrollView.alwaysBounceHorizontal = false
        
        scrollView.showsVerticalScrollIndicator = false
        scrollView.showsHorizontalScrollIndicator = false
        
        scrollView.minimumZoomScale = 1.0
        scrollView.maximumZoomScale = 10.0
        
        scrollView.addSubview(innerImageView)
        
        return scrollView
    }()
    
    private lazy var innerImageView: UIImageView = {
        
        var width = contentView.frame.width
        var height = contentView.frame.height
        
        var imageView = UIImageView(frame: CGRect(x: 0, y: 0, width: width, height: height))
        
        imageView.clipsToBounds = true
        
        imageView.contentMode = .scaleAspectFit
        
        return imageView
    }()
    
    func configure(with scannedItem: ScannedItem) {
        
        innerImageView.image = scannedItem.newRenderedImage?.retrieveImage()
        
        contentView.addSubview(scrollView)
    }
    
    func resetZoomScale() {
        
        scrollView.zoomScale = 1.0
    }
}

extension ScannedItemPreviewPagerViewCell: UIScrollViewDelegate {
    
    func viewForZooming(in scrollView: UIScrollView) -> UIView? {
        innerImageView
    }
}
