//
//  DocumentsCollectionViewCell.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/29/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit

class DocumentsCollectionViewCell: UICollectionViewCell {
    
    @IBOutlet private weak var imageView: UIImageView!
    @IBOutlet private weak var nameLabel: UILabel!
    @IBOutlet private weak var detailsLabel: UILabel!
    @IBOutlet private weak var dateLabel: UILabel!
    @IBOutlet weak var extraButton: UIButton!
    
    weak var delegate: DocumentsCellDelegate?
    
    override func awakeFromNib() {
        super.awakeFromNib()
        
        setupUI()
    }
    
    func configure(with session: ScanSession, indexPath: IndexPath) {
        
        nameLabel.set(text: session.name)
        
        let details = String.dPages.localizedPlural(argument: session.itemsCount)
        
        detailsLabel.set(text: details)
        
        dateLabel.set(text: session.creatingDateString.localized)
        
        setupMenu(indexPath: indexPath)
    }
    
    private func setupUI() {
        
        setupColors()
        setupFonts()
        
        contentView.cornerRadiuss = 20
        contentView.borderWidth = 2
        
        extraButton.showsMenuAsPrimaryAction = true
        extraButton.transform = extraButton.transform.rotated(by: .pi/2)
        
        imageView.image = .file
    }
    
    private func setupColors() {
        
        contentView.customBackground(.gray100)
        contentView.customBorderColor(.gray0)
        
        extraButton.customTint(.gray600)
        
        nameLabel.set(color: .gray600)
        detailsLabel.set(color: .gray600)
        dateLabel.set(color: .gray600)
    }
    
    private func setupFonts() {
        
        nameLabel.set(font: .semibold(16))
        
        detailsLabel.set(font: .regular(10))
        dateLabel.set(font: .regular(10))
    }
    
    private func setupMenu(indexPath: IndexPath) {
        
        let move = UIAction(title: .move.localized) { _ in
            self.delegate?.moveScanSession(at: indexPath)
        }
        
        let rename = UIAction(title: .rename.localized, image: .squareAndPencil) { _ in
            self.delegate?.renameScanSession(at: indexPath)
        }
        
        let delete = UIAction(title: .delete.localized, image: .trash, attributes: .destructive) { _ in
            self.delegate?.deleteScanSession(at: indexPath)
        }
        
        let menu = UIMenu(title: "", children: [move, rename, delete])
        
        extraButton.menu = menu
    }
}
