//
//  DocumentsTableViewCell.swift
//  MiniScanner
//
//  Created by George Makhoul on 08/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit

final class DocumentsTableViewCell: UITableViewCell {
    
    @IBOutlet private weak var thumbnailImageView: UIImageView!
    @IBOutlet private weak var nameLabel: UILabel!
    @IBOutlet weak var extraButton: UIButton!
    @IBOutlet private weak var dateLabel: UILabel!
    
    @IBOutlet weak var innerView: UIView!
    
    weak var delegate: DocumentsCellDelegate?
    
    override func awakeFromNib() {
        super.awakeFromNib()
        // Initialization code
        
        setupUI()
    }
    
    func configure(with session: ScanSession,
                   indexPath: IndexPath) {
        
        nameLabel.set(text: session.name)
        
        let description = "\(session.creatingDateString.localized) - \(String.dPages.localizedPlural(argument: session.itemsCount))"
        
        dateLabel.set(text: description)
        
        setupMenu(indexPath: indexPath)
    }
    
    private func setupUI() {
        
        setupColors()
        
        setupFonts()
        
        selectionStyle = .none
        
        innerView.cornerRadiuss = 20
        
        extraButton.showsMenuAsPrimaryAction = true
        extraButton.transform = extraButton.transform.rotated(by: .pi/2)
        
        thumbnailImageView.image = .file
    }
    
    private func setupColors() {
        
        innerView.customBorderColor(.gray0)
        innerView.customBackground(.gray100)
        
        dateLabel.set(color: .gray600)
        nameLabel.set(color: .gray600)
        
        extraButton.customTint(.gray600)
    }
    
    private func setupFonts() {
        
        nameLabel.set(font: .semibold(16))
        dateLabel.set(font: .regular(12))
    }
    
    private func setupMenu(indexPath: IndexPath) {
        
        let move = UIAction(title: .move.localized) { _ in
            self.delegate?.moveScanSession(at: indexPath)
        }
        
        let rename = UIAction(title: .rename.localized, image: .squareAndPencil) { _ in
            self.delegate?.renameScanSession(at: indexPath)
        }
        
        let delete = UIAction(title: .delete.localized, image: .trash, attributes: .destructive) { _ in
            self.delegate?.deleteScanSession(at: indexPath)
        }
        
        let menu = UIMenu(title: "", children: [move, rename, delete])
        
        extraButton.menu = menu
    }
}
