//
//  FolderCollectionViewCell.swift
//  MiniScanner
//
//  Created by George Makhoul on 06/06/2024.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit

protocol FolderCollectionViewCellDelegate: AnyObject {
    func deleteFolder(folder: Folder)
}

class FolderCollectionViewCell: UICollectionViewCell {
    // MARK: - Outlets
    @IBOutlet weak var boxView: UIView!
    @IBOutlet weak var titleLabel: UILabel!
    @IBOutlet weak var deleteButton: UIButton!
    
    @IBOutlet weak var deleteButtonWidthConstraint: NSLayoutConstraint!
    // MARK: - Properties
    var isFolderSelected: Bool = false
    var canBeDeleted: Bool = false
    
    var folder: Folder?
    
    weak var delegate: FolderCollectionViewCellDelegate?
    
    // MARK: - LifeCycle
    override func awakeFromNib() {
        super.awakeFromNib()
        setupUI()
    }
    
    private func setupUI() {
        setupColors()
        
        boxView.cornerRadiuss = 10
        boxView.clipsToBounds = false
    }
    
    private func setSelected() {
        
        boxView.customBackground(isFolderSelected ? .primary : .gray100)
        
        titleLabel.set(font: isFolderSelected ? .bold(16) : .medium(16))
        
        titleLabel.set(color: isFolderSelected ? .gray0 : .gray600)
    }
    
    private func handleDeleteButton() {
        
        deleteButton.isHidden = !(canBeDeleted && isFolderSelected)
        
        deleteButtonWidthConstraint.constant = deleteButton.isHidden ? 0 : 34
    }
    
    func set(folder: Folder) {
        
        isFolderSelected = folder.isSelected
        canBeDeleted = folder.canBeDeleted
        
        self.folder = folder
        
        titleLabel.set(text: folder.localizedName)
        
        titleLabel.align(to: .center)
        
        setSelected()
        
        handleDeleteButton()
    }
    
    private func setupColors() {
        boxView.customBackground(.gray100)
        
        titleLabel.set(color: isFolderSelected ? .primaryText : .gray600)
        deleteButton.customTint(.gray0)
    }
    
    @IBAction func deleteTapped(_ sender: Any) {
        delegate?.deleteFolder(folder: folder!)
    }
}
