//
//  CustomTabBarLayerProtocol.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 7/22/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import Foundation

protocol CustomTabBarLayerProtocol: UIView {
    
    var shapeLayer: CALayer? { get set }
    var buttonSize: CGFloat { get }
    func draw(_ rect: CGRect)
    func addShape()
    func createPath() -> CGPath
}

extension CustomTabBarLayerProtocol {
    
    func addShape() {
        let shapeLayer = CAShapeLayer()
        shapeLayer.path = createPath()
        
        let tabBackColor = ColorStyle.gray0.uiColor
        shapeLayer.fillColor = tabBackColor.cgColor
        shapeLayer.lineWidth = 0.5
        
        //The below 4 lines are for shadow above the bar. you can skip them if you do not want a shadow
        shapeLayer.shadowOffset = CGSize(width:0, height:0)
        shapeLayer.shadowRadius = 10
        shapeLayer.shadowColor = UIColor.gray.cgColor
        shapeLayer.shadowOpacity = 0.3
        
        if let oldShapeLayer = self.shapeLayer {
            self.layer.replaceSublayer(oldShapeLayer, with: shapeLayer)
        } else {
            self.layer.insertSublayer(shapeLayer, at: 0)
        }
        self.shapeLayer = shapeLayer
    }
    
    func createPath() -> CGPath {
        
        let path = UIBezierPath()
        
        let buttonSize = buttonSize
        
        let frameWidth: CGFloat = self.frame.width
        let frameHeight: CGFloat = self.frame.height
        
        let centerWidth = frameWidth / 2
        let centerHeight = frameHeight / 2
        
        let startPoint = CGPoint(x: 0, y: centerHeight)
        
        path.move(to: startPoint)
        
        path.addArc(withCenter: CGPoint(x: centerHeight, y: centerHeight),
                    radius: centerHeight,
                    startAngle: .pi,
                    endAngle: -.pi/2,
                    clockwise: true)
        
        path.addLine(to: CGPoint(x: centerWidth - (buttonSize / 2 + 10), y: 0))
        
        path.addArc(withCenter: CGPoint(x: centerWidth, y: 0),
                    radius: buttonSize / 2 + 10,
                    startAngle: CGFloat.pi,
                    endAngle: 0,
                    clockwise: false)
        
        path.addLine(to: CGPoint(x: centerWidth + (buttonSize / 2 + 10), y: 0))
        
        path.addArc(withCenter: CGPoint(x: frameWidth - centerHeight, y: centerHeight),
                    radius: centerHeight,
                    startAngle: -.pi/2,
                    endAngle: 0,
                    clockwise: true)
        
        path.addLine(to: CGPoint(x: frameWidth, y: frameHeight))
        
        path.addLine(to: CGPoint(x: 0, y: frameHeight))
        
        path.close()
        
        return path.cgPath
    }
}
