import Foundation
import PDFKit

/// File is a class representing a file in iFinder
class File: NSObject {
  /// Display name. String.
  let displayName: String
  /// File extension.
  var fileExtension: String?
  /// File attributes (including size, creation date etc).
  let fileAttributes: NSDictionary?
  /// URL file path.
  let fileURL: URL
  /// Creation Date
  let date: String
  // Page numbers
  let pagesCount: String
  // File size
  let size: String
  // pdf document
  var pdfDocument: PDFDocument?
  
  /**
   Initialize an File object with a filePath
   - parameter filePath: URL filePath
   - returns: File object.
   */
  init(fileURL: URL) {
    self.fileURL = fileURL
    self.displayName = fileURL.deletingPathExtension().lastPathComponent
    self.fileExtension = fileURL.pathExtension
    self.fileAttributes = fileURL.getFileAttributes
    self.fileExtension = fileURL.pathExtension
    self.date = fileURL.getDate
    pdfDocument = PDFDocument(url: fileURL)
      
    self.size = fileURL.getSizeString
      
    let pagesCount = pdfDocument?.pageCount ?? 1
    let text = String.dPages.localizedPlural(argument: pagesCount)
      
    self.pagesCount = text // "\(pdfDocument?.pageCount ?? 1) pages"
  }
}
