//
//  DefaultSignatureSheetViewController.swift
//  MiniScanner
//
//  Created by Mustafa Merza on 8/15/24.
//  Copyright © 2024 AppsNectar. All rights reserved.
//

import UIKit

protocol DefaultSignatureSheetViewControllerDelegate: AnyObject {
    func useDefaultSignature()
    func deleteDefaultSignature()
}

class DefaultSignatureSheetViewController: UIViewController {
    
    @IBOutlet weak var backgroundView: UIView!
    
    @IBOutlet weak var useDefaultSignatureButton: UIButton!
    @IBOutlet weak var deleteDefaultSignatureButton: UIButton!
    
    weak var delegate: DefaultSignatureSheetViewControllerDelegate?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
    }
    
    init(delegate: DefaultSignatureSheetViewControllerDelegate) {
        self.delegate = delegate
        super.init(nibName: nil, bundle: nil)
    }
    
    required public init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    private func setupUI() {
        
        setupColors()
        
        setupFonts()
        
        backgroundView.layer.cornerRadius = 30
        backgroundView.layer.maskedCorners = [.layerMinXMinYCorner, .layerMaxXMinYCorner]
        
        useDefaultSignatureButton.set(localized: .useDefaultSignature)
        
        deleteDefaultSignatureButton.set(localized: .deleteDefaultSignature)
    }
    
    private func setupColors() {
        
        backgroundView.customBackground(.base)
        
        useDefaultSignatureButton.customTint(.primary)
        
        deleteDefaultSignatureButton.customTint(.statusFalse)
    }
    
    private func setupFonts() {
        useDefaultSignatureButton.set(font: .medium(18))
        deleteDefaultSignatureButton.set(font: .medium(18))
    }
    
    @IBAction func onTouchUseDefaultSignatureButton(_ sender: Any) {
        delegate?.useDefaultSignature()
        
        dismiss(animated: true)
    }
    
    @IBAction func onTouchDeleteDefaultSignatureButton(_ sender: Any) {
        delegate?.deleteDefaultSignature()
        
        dismiss(animated: true)
    }
}
